.App{text-align:center}.App-logo{height:40vmin;pointer-events:none}@media (prefers-reduced-motion:no-preference){.App-logo{-webkit-animation:App-logo-spin 20s linear infinite;animation:App-logo-spin 20s linear infinite}}.App-header{background-color:#282c34;min-height:100vh;display:flex;flex-direction:column;align-items:center;justify-content:center;font-size:calc(10px + 2vmin);color:#fff}.App-link{color:#61dafb}@-webkit-keyframes App-logo-spin{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}@keyframes App-logo-spin{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}.flowLeft{stroke-dasharray:5;-webkit-animation:dashdrawLeft 5s linear infinite;animation:dashdrawLeft 5s linear infinite}@-webkit-keyframes dashdrawLeft{to{stroke-dashoffset:200}}@keyframes dashdrawLeft{to{stroke-dashoffset:200}}.flowRight{stroke-dasharray:5;-webkit-animation:dashdrawRight 5s linear infinite;animation:dashdrawRight 5s linear infinite}@-webkit-keyframes dashdrawRight{to{stroke-dashoffset:-200}}@keyframes dashdrawRight{to{stroke-dashoffset:-200}}circle{pointer-events:auto}.shadow{-webkit-filter:drop-shadow(3px 3px 2px rgba(0,0,0,.7));filter:drop-shadow(3px 3px 2px rgba(0,0,0,.7))}.box{padding:0;box-shadow:-2px 2px 5px #000}.handle,.section_header{background-color:#3a383b;padding:5px}.no-drag{user-drag:none;-moz-user-select:none;-webkit-user-drag:none}.container{background-size:cover;background:#e2e2e2;background:linear-gradient(180deg,#e2e2e2 0,#dbdbdb 50%,#d1d1d1 51%,#fefefe);filter:progid:DXImageTransform.Microsoft.gradient(startColorstr="#e2e2e2",endColorstr="#fefefe",GradientType=0);padding:20px}.led-box{height:30px;width:25%;margin:10px 0;float:left}.led-box p{font-size:12px;text-align:center;margin:1em}.led-red{margin:0 auto;width:24px;height:24px;background-color:red;border-radius:50%;box-shadow:0 -1px 7px 1px rgba(0,0,0,.2),inset 0 -1px 9px #441313,0 2px 12px rgba(255,0,0,.5);-webkit-animation:blinkRed .5s infinite;animation:blinkRed .5s infinite}@-webkit-keyframes blinkRed{0%{background-color:red}50%{background-color:#a00;box-shadow:0 -1px 7px 1px rgba(0,0,0,.2),inset 0 -1px 9px #441313,0 2px 0 rgba(255,0,0,.5)}to{background-color:red}}@keyframes blinkRed{0%{background-color:red}50%{background-color:#a00;box-shadow:0 -1px 7px 1px rgba(0,0,0,.2),inset 0 -1px 9px #441313,0 2px 0 rgba(255,0,0,.5)}to{background-color:red}}.led-yellow{margin:0 auto;width:24px;height:24px;background-color:#ff0;border-radius:50%;box-shadow:0 -1px 7px 1px rgba(0,0,0,.2),inset 0 -1px 9px #808002,0 2px 12px #ff0;-webkit-animation:blinkYellow 1s infinite;animation:blinkYellow 1s infinite}@-webkit-keyframes blinkYellow{0%{background-color:#ff0}50%{background-color:#aa0;box-shadow:0 -1px 7px 1px rgba(0,0,0,.2),inset 0 -1px 9px #808002,0 2px 0 #ff0}to{background-color:#ff0}}@keyframes blinkYellow{0%{background-color:#ff0}50%{background-color:#aa0;box-shadow:0 -1px 7px 1px rgba(0,0,0,.2),inset 0 -1px 9px #808002,0 2px 0 #ff0}to{background-color:#ff0}}.led-green{background-color:#abff00;box-shadow:0 -1px 7px 1px rgba(0,0,0,.2),inset 0 -1px 9px #304701,0 2px 12px #89ff00}.led-green,.led-green-off{margin:0 auto;width:24px;height:24px;border-radius:50%}.led-green-off{background-color:#557f00;box-shadow:0 -1px 7px 1px rgba(0,0,0,.2),inset #304701}.led-blue{margin:0 auto;width:24px;height:24px;background-color:#24e0ff;border-radius:50%;box-shadow:0 -1px 7px 1px rgba(0,0,0,.2),inset 0 -1px 9px #006,0 2px 14px #3f8cff}body{margin:0;font-family:"JetBrains Mono";-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;background-color:#272227;color:#fff}body,html{touch-action:none}code{font-family:source-code-pro,Menlo,Monaco,Consolas,"Courier New",monospace}.loadingbg{background:#212120;background:radial-gradient(circle,#212120 8%,#131313 93%);filter:progid:DXImageTransform.Microsoft.gradient(startColorstr="#212120",endColorstr="#131313",GradientType=1)}
/*# sourceMappingURL=main.c53dbdb4.chunk.css.map */